@@ -26,3 +26,22 @@ sub response_filter {
 }
 
 1;
+__END__
+
+=for stopwords localsrc HTML
+
+=head1 NAME
+
+Moxy::Plugin::HTMLWidth - limit the HTML width
+
+=head1 SYNOPSIS
+
+  - module: HTMLWidth
+
+=head1 DESCRIPTION
+
+limit the HTML width
+
+=head1 SEE ALSO
+
+L<Moxy>
