@@ -17,6 +17,16 @@ sub register {
 1;
 __END__
 
+=for stopwords: html xml
+
+=head1 NAME
+
+Moxy::Plugin::XMLisHTML - XML is HTML
+
+=head1 SYNOPSIS
+
+    - module: XMLisHTML
+
 =head1 DESCRIPTION
 
 If you want to use the CSS, DoCoMo UA needs to use 'application/xhtml+xml' for Content-Type.
@@ -24,3 +34,11 @@ But, DoCoMo's XHTML is not valid, likes '<a href="/login" utn>login</a>', Firefo
 
 This plugin replace Content-Type header.
 
+=head1 AUTHORS
+
+Tokuhiro Matsuno
+
+=head1 SEE ALSO
+
+L<Moxy>
+
